@@ -1,6 +1,8 @@
-import qlat_grid.c as cg
+import qlat_grid.c as c
 
 from qlat_grid.init import *
 from qlat_grid.prop import *
 
 from qlat_grid.get_include_dir import *
+
+del c
